r223987 - Revert r223578, perf data collection depends on the old symbol name.

Paul Robinson paul_robinson at playstation.sony.com
Wed Dec 10 15:49:03 PST 2014


Author: probinson
Date: Wed Dec 10 17:49:03 2014
New Revision: 223987

URL: http://llvm.org/viewvc/llvm-project?rev=223987&view=rev
Log:
Revert r223578, perf data collection depends on the old symbol name.

Modified:
    cfe/trunk/lib/Basic/CMakeLists.txt
    cfe/trunk/lib/Basic/Makefile
    cfe/trunk/lib/Basic/Version.cpp

Modified: cfe/trunk/lib/Basic/CMakeLists.txt
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Basic/CMakeLists.txt?rev=223987&r1=223986&r2=223987&view=diff
==============================================================================
--- cfe/trunk/lib/Basic/CMakeLists.txt (original)
+++ cfe/trunk/lib/Basic/CMakeLists.txt Wed Dec 10 17:49:03 2014
@@ -38,7 +38,7 @@ if(DEFINED llvm_vc AND DEFINED clang_vc)
     ${CMAKE_COMMAND} "-DFIRST_SOURCE_DIR=${LLVM_MAIN_SRC_DIR}"
                      "-DFIRST_NAME=LLVM"
                      "-DSECOND_SOURCE_DIR=${CLANG_SOURCE_DIR}"
-                     "-DSECOND_NAME=CLANG"
+                     "-DSECOND_NAME=SVN"
                      "-DHEADER_FILE=${version_inc}"
                      -P "${get_svn_script}")
 

Modified: cfe/trunk/lib/Basic/Makefile
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Basic/Makefile?rev=223987&r1=223986&r2=223987&view=diff
==============================================================================
--- cfe/trunk/lib/Basic/Makefile (original)
+++ cfe/trunk/lib/Basic/Makefile Wed Dec 10 17:49:03 2014
@@ -16,10 +16,10 @@ LIBRARYNAME := clangBasic
 
 include $(CLANG_LEVEL)/Makefile
 
-CLANG_REVISION := $(strip \
+SVN_REVISION := $(strip \
         $(shell $(LLVM_SRC_ROOT)/utils/GetSourceVersion $(PROJ_SRC_DIR)/../..))
 
-CLANG_REPOSITORY := $(strip \
+SVN_REPOSITORY := $(strip \
         $(shell $(LLVM_SRC_ROOT)/utils/GetRepositoryPath $(PROJ_SRC_DIR)/../..))
 
 LLVM_REVISION := $(strip \
@@ -29,12 +29,12 @@ LLVM_REPOSITORY := $(strip \
         $(shell $(LLVM_SRC_ROOT)/utils/GetRepositoryPath $(LLVM_SRC_ROOT)))
 
 CPP.Defines += -I$(PROJ_SRC_DIR)/../../include -I$(PROJ_OBJ_DIR)/../../include \
-         -DCLANG_REVISION='"$(CLANG_REVISION)"' -DCLANG_REPOSITORY='"$(CLANG_REPOSITORY)"' \
+         -DSVN_REVISION='"$(SVN_REVISION)"' -DSVN_REPOSITORY='"$(SVN_REPOSITORY)"' \
          -DLLVM_REVISION='"$(LLVM_REVISION)"' -DLLVM_REPOSITORY='"$(LLVM_REPOSITORY)"'
 
 $(ObjDir)/.ver-svn .ver: $(ObjDir)/.dir
-	@if [ '$(CLANG_REVISION) $(LLVM_REVISION)' != '$(shell cat $(ObjDir)/.ver-svn 2>/dev/null)' ]; then\
-		echo '$(CLANG_REVISION) $(LLVM_REVISION)' > $(ObjDir)/.ver-svn;                    \
+	@if [ '$(SVN_REVISION) $(LLVM_REVISION)' != '$(shell cat $(ObjDir)/.ver-svn 2>/dev/null)' ]; then\
+		echo '$(SVN_REVISION) $(LLVM_REVISION)' > $(ObjDir)/.ver-svn;                    \
 	fi
 $(ObjDir)/.ver-svn: .ver
 $(ObjDir)/Version.o: $(ObjDir)/.ver-svn

Modified: cfe/trunk/lib/Basic/Version.cpp
URL: http://llvm.org/viewvc/llvm-project/cfe/trunk/lib/Basic/Version.cpp?rev=223987&r1=223986&r2=223987&view=diff
==============================================================================
--- cfe/trunk/lib/Basic/Version.cpp (original)
+++ cfe/trunk/lib/Basic/Version.cpp Wed Dec 10 17:49:03 2014
@@ -28,13 +28,13 @@ std::string getClangRepositoryPath() {
 #if defined(CLANG_REPOSITORY_STRING)
   return CLANG_REPOSITORY_STRING;
 #else
-#ifdef CLANG_REPOSITORY
-  StringRef URL(CLANG_REPOSITORY);
+#ifdef SVN_REPOSITORY
+  StringRef URL(SVN_REPOSITORY);
 #else
   StringRef URL("");
 #endif
 
   // If the CLANG_REPOSITORY is empty, try to use the SVN keyword. This helps us
   // pick up a tag in an SVN export, for example.
   StringRef SVNRepository("$URL$");
   if (URL.empty()) {
@@ -72,8 +72,8 @@ std::string getLLVMRepositoryPath() {
 }
 
 std::string getClangRevision() {
-#ifdef CLANG_REVISION
-  return CLANG_REVISION;
+#ifdef SVN_REVISION
+  return SVN_REVISION;
 #else
   return "";
 #endif
@@ -28,13 +28,13 @@ std::string getClangRepositoryPath() {
 #endif
 
-  // If the CLANG_REPOSITORY is empty, try to use the SVN keyword. This helps us
+  // If the SVN_REPOSITORY is empty, try to use the SVN keyword. This helps us
   // pick up a tag in an SVN export, for example.
   StringRef SVNRepository("$URL$");





More information about the cfe-commits mailing list